==> wxPostgres-0.2.1.tar.gz: wxPostgres/wxPg/binding/row_binding.h <==
/* row_binding.h - binding wxWindow to display value of some
    field in wxPg::Data_row

    Copyright (C) 2008, 2009 Aurimas Černius

    This file is part of wxPostgres.

    wxPostgres is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    wxPostgres is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with wxPostgres.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef __ROW_BINDING_H
#define __ROW_BINDING_H

#include "wxPg/conf.h"
#include "wxPg/binding/binding.h"
#include "wxPg/db/data_row_provider.h"
#include<map>

namespace wxPg{

/** Binding widgets to display values from wxPg::Data_row. */
class wxPG_DECLSPEC
Row_binding : public Binding{
public:
    /** Function, responsible for setting value of widget. */
    typedef void (*upd_ctrl_f)(wxWindow*, const wxString&,
                               Data_row_provider*);

    /** Creates new object.
        Call data() to complete initialization of object.
    */
    Row_binding();

    /** Creates new object.
        @param data - a row of query result to be used.
    */
    explicit
    Row_binding(Data_row_provider *data);

    /** Destroys the object. */
    virtual
    ~Row_binding(){}

    /** Returns currently used data row.
        @return currently used data row.
    */
    Data_row_provider*
    data();

    /** Sets currently used data row.
        @param data - new data row to be used.
    */
    void
    data(Data_row_provider *data);

    /** Binds widget.
        When update_UI() is called, the value of widget is set to the value
        of field.
        Usually you don't need to call this method directly -
        use binding macros, defined in binding_macros.h.
        @param w - widget to be binded.
        @param field - database field.
        @param f - function, responsible for setting control value.
    */
    void
    bind(wxWindow *w, wxString field, upd_ctrl_f f);

    /** Unbind widget.
        @param w is no longer updated.
    */
    virtual void
    unbind(wxWindow *w);

    /** Update UI.
        Sets values of binded widgets to specified field values.
    */
    virtual void
    update_UI();
protected:
    //data row to bind
    Data_row_provider*
    data_;

    //binding type
    typedef std::pair<wxString, upd_ctrl_f>
    ctrl_binding;

    //widget bindings
    std::map<wxWindow*, ctrl_binding>
    ctrl_bindings_;
private:
    Row_binding(const Row_binding&){}
    Row_binding &operator=(const Row_binding&){return *this;}
};

}

#endif

==> wxPostgres-0.3.1.tar.gz: wxPostgres/wxPg/binding/row_binding.h <==
/* row_binding.h - binding wxWindow to display value of some
    field in wxPg::Data_row

    Copyright (C) 2008, 2009 Aurimas Černius

    This file is part of wxPostgres.

    wxPostgres is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    wxPostgres is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with wxPostgres.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef __ROW_BINDING_H
#define __ROW_BINDING_H

#include "wxPg/conf.h"
#include "wxPg/binding/binding.h"
#include "wxPg/db/data_row_provider.h"
#include "wxPg/binding/binding_ctrl.h"
#include<vector>

namespace wxPg{

/** Binding widgets to display values from wxPg::Data_row. */
class wxPG_DECLSPEC
Row_binding : public Binding{
public:
    /** Creates new object.
        Call data() to complete initialization of object.
    */
    Row_binding();

    /** Creates new object.
        @param data - a row of query result to be used.
    */
    explicit
    Row_binding(Data_row_provider *data);

    /** Destroys the object. */
    virtual
    ~Row_binding();

    /** Returns currently used data row.
        @return currently used data row.
    */
    Data_row_provider*
    data(){return this->data_;}

    /** Sets currently used data row.
        @param data - new data row to be used.
    */
    void
    data(Data_row_provider *data){this->data_ = data;}

    /** Binds widget.
        When update_UI() is called, updater is called with this as argument.\n
        Usually you don't need to call this method directly -
        use binding macros, defined in binding_macros.h. Use this for your own
        wxWindow_updater descendant.
        @param updater - function object, responsible for setting
        control value.
    */
    void
    bind(wxWindow_updater *updater);

    /** Unbind widget.
        @param w is no longer updated.
    */
    virtual void
    unbind(wxWindow *w);

    /** Update UI.
        Sets values of binded widgets to specified field values.
    */
    virtual void
    update_UI();
protected:
    //data row to bind
    Data_row_provider*
    data_;

    //widget bindings
    std::vector<wxWindow_updater*>
    ctrl_bindings_;
private:
    Row_binding(const Row_binding&){}
    Row_binding &operator=(const Row_binding&){return *this;}
};

}

#endif
